@@ -5,6 +5,9 @@
 
 # -- Project information -----------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
+import sys
+
+sys.path.insert(0, "../")
 
 project = 'sphinx_expose_init_alias'
 copyright = '2022, cmsxbc'
