@@ -1,5 +1,6 @@
 from sphinx_expose_init_alias.documenter import AliasDocumenter
 from sphinx_expose_init_alias.documenter import AliasModuleDocumenter
+import sphinx.application as sphinx_app
 
 
 def maybe_skip_member(app, what, name, obj, skip, options):
@@ -7,7 +8,7 @@ def maybe_skip_member(app, what, name, obj, skip, options):
         return False
 
 
-def setup(app):
+def setup(app: sphinx_app):
     app.setup_extension('sphinx.ext.autodoc')  # Require autodoc extension
     app.add_autodocumenter(AliasDocumenter)
     app.add_autodocumenter(AliasModuleDocumenter)
